using System;
using System.Windows;
using System.Windows.Interactivity;

namespace FocusVMLib.Behaviors
{
  public abstract class FocusBehaviorBase : Behavior<FrameworkElement>
  {
    /// <summary>
    /// The behaviour does not know to which property the user is binding. Accordingly,
    /// the implementing class needs to deliver that information.
    /// </summary>
    /// <returns>The property that is bound to a property that determines whether the
    /// control gets focus or not.</returns>
    protected abstract DependencyProperty GetSourceProperty();



    /// <summary>
    /// Wires the associated object with the <see cref="FocusController"/>, which in turn
    /// makes sure the object is properly focused when necessary.
    /// </summary>
    protected override void OnAttached()
    {
      FocusController.SetFocusableProperty(AssociatedObject, GetSourceProperty());
    }

  }
}